web/request.py
changeset 8496 e4d71fc0b701
parent 8316 d5b1b75805dd
child 8535 268b6349baf3
--- a/web/request.py	Tue Jul 24 15:06:55 2012 +0200
+++ b/web/request.py	Tue Jul 24 17:51:00 2012 +0200
@@ -96,9 +96,9 @@
         super(CubicWebRequestBase, self).__init__(vreg)
         #: (Boolean) Is this an https request.
         self.https = https
         #: User interface property (vary with https) (see uiprops_)
         self.uiprops = None
         #: url for serving datadir (vary with https) (see resources_)
         self.datadir_url = None
         if https:
             self.uiprops = vreg.config.https_uiprops
@@ -171,7 +171,7 @@
     def authmode(self):
         """Authentification mode of the instance
 
-        (see `Configuring the Web server`_)"""
+        (see :ref:`Configuring the Web server`)"""
         return self.vreg.config['auth-mode']
 
     # Various variable generator.
@@ -96,9 +96,9 @@
         #: (Boolean) Is this an https request.
         self.https = https
-        #: User interface property (vary with https) (see uiprops_)
+        #: User interface property (vary with https) (see :ref:`uiprops`)
         self.uiprops = None
@@ -96,9 +96,9 @@
         self.uiprops = None
-        #: url for serving datadir (vary with https) (see resources_)
+        #: url for serving datadir (vary with https) (see :ref:`resources`)
         self.datadir_url = None
         if https: